# fontdialog.py

########################################################################
#  SdiQt -- SDictionary viewer based on Qt library
#  Copyright (C) 2006 Dmitri Brechalov
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#  The full license is in the file COPYING, distributed as part of
#  this software.
########################################################################

import os.path
from qt import *
import qtpe
import utils

class FontDialog(QDialog):

    def __init__(self, parent, font=None, name=None):
        QDialog.__init__(self,parent,name,1,0)

        if not name:
            self.setName("FontDialog")

        if font:
            self.__font = font
        else:
            self.__font = self.font()
        self.__fd = qtpe.FontDatabase()

        FontDialogLayout = QVBoxLayout(self,11,6,"FontDialogLayout")
        gridLayout = QGridLayout(None, 1, 1, 11, 6, "GridLauout")
        label1 = QLabel(self, "label1")
        label1.setText("Font:")
        gridLayout.addWidget(label1, 0, 0)
        self.familyList = QComboBox(self, 'familyList')
        gridLayout.addWidget(self.familyList, 0, 1)
        label2 = QLabel(self, "label2")
        label2.setText("Size:")
        gridLayout.addWidget(label2, 1, 0)
        self.sizeList = QComboBox(self, 'sizeList')
        gridLayout.addWidget(self.sizeList, 1, 1)
        FontDialogLayout.addLayout(gridLayout)
        self.connect(self.familyList,SIGNAL("activated(const QString &)"),self.familyChanged)
        self.__setupFont()

        #### Buttons Ok and Cancel
        if not utils.isQtopia():
            layout10 = QHBoxLayout(None,0,6,"layout10")

            self.btnOk = QPushButton(self,"btnOk")
            self.btnOk.setText("O&K")
            layout10.addWidget(self.btnOk)

            self.btnCancel = QPushButton(self,"btnCancel")
            self.btnCancel.setText("&Cancel")
            layout10.addWidget(self.btnCancel)
            FontDialogLayout.addLayout(layout10)

            self.btnOk.setDefault(True)
            self.connect(self.btnOk,SIGNAL("clicked()"),self.accept)
            self.connect(self.btnCancel,SIGNAL("clicked()"),self.reject)

        self.setCaption("Select Font")
        self.resize(QSize(160,140).expandedTo(self.minimumSizeHint()))

    def __setupFont(self):
        self.familyList.clear()
        families = self.__fd.families()
        curfam = self.__font.family()
        self.familyList.insertStringList(families)
        for i in range(families.count()):
            if families[i] == curfam:
                self.familyList.setCurrentItem(i)
                self.familyChanged(curfam)
                break

    def familyChanged(self, familyName):
        cursize = self.__font.pointSize()
        fontsizes = self.__fd.pointSizes(familyName)
        self.sizeList.clear()
        if not fontsizes:
            return
        #### bug in FontDatabase.pointSizes
        self.__scale = min(fontsizes) >= 50 and 10 or 1
        for i in range(len(fontsizes)):
            size = fontsizes[i]  / self.__scale
            self.sizeList.insertItem(str(size))
            if size == cursize:
                self.sizeList.setCurrentItem(i)

    def selectedFont(self):
        font = self.__font
        font.setFamily(self.familyList.text(self.familyList.currentItem()))
        size = int(str(self.sizeList.text(self.sizeList.currentItem()).utf8())) #* self.__scale
        font.setPointSize(size)
        return font

# fontdialog.py
